@@ -426,7 +426,19 @@ class Path:
 			show_size=self._show_size
 		)
 
-	__add__ = __truediv__
+	def __add__(self, other):
+		"""
+		:type other: str
+		:rtype: S3Path
+		"""
+		if isinstance(other, str):
+			if other.startswith('.'):  # other is an extension
+				left = self._path.rstrip('/')
+				return self.__class__(s3=self.s3, path=f'{left}{other}')
+			else:
+				return self.__truediv__(other)
+		else:
+			return self.__truediv__(other)
 
 	def _sort_key(self):
 		return self.type, self.get_absolute()
@@ -547,9 +559,14 @@ class Path:
 		delete_dir(path=(self+name).path)
 
 	def save(self, obj, method='pickle', mode='wb', echo=0):
+		path = self.path
+		if not path.endswith('.pickle'):
+			path += '.pickle'
+
 		if not self.parent_directory.exists():
 			self.parent_directory.make_dir()
-		_pickle(path=self.path, obj=obj, method=method, mode=mode, echo=echo)
+		_pickle(path=path, obj=obj, method=method, mode=mode, echo=echo)
+		return path
 
 	def load(self, method='pickle', mode='rb', echo=0):
 		"""
